#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAXIMUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAXIMUM_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/maximum.hpp>

#endif
